@@ -1,7 +1,6 @@
 import importlib
 
 from django.conf import settings
-from django.templatetags.static import static
 from django.utils.translation import get_language
 
 from ephios.core.models import AbstractParticipation
@@ -17,14 +16,10 @@ def ephios_base_context(request):
         for label, url in result.items():
             footer[label] = url
 
-    datatables_translation_url = None
-    if get_language() == "de-de":
-        datatables_translation_url = static("datatables/german.json")
-
     return {
         "ParticipationStates": AbstractParticipation.States,
         "footer": footer,
-        "datatables_translation_url": datatables_translation_url,
+        "LANGUAGE_CODE": get_language(),
         "ephios_version": EPHIOS_VERSION,
         "SITE_URL": settings.SITE_URL,
         "PWA_APP_ICONS": settings.PWA_APP_ICONS,
