@@ -157,11 +157,11 @@ class UserProfile(guardian.mixins.GuardianUserMixin, PermissionsMixin, AbstractB
                 hours=ExpressionWrapper(
                     (
                         F("shift__end_time") - F("shift__start_time")
-                    )  # calculate length of shift in μs
-                    / 1000000  # convert microseconds to seconds
-                    / 3600,  # convert seconds to hours
-                    output_field=models.DecimalField(),
-                ),
+                    ),  # calculate length of shift in μs
+                    output_field=models.IntegerField(),
+                )
+                / 1000000
+                / 3600,  # convert microseconds to seconds to hours
                 date=ExpressionWrapper(TruncDate(F("shift__start_time")), output_field=DateField()),
                 reason=F("shift__event__title"),
             )
@@ -181,7 +181,6 @@ register_model_for_logging(
     ),
 )
 
-
 register_model_for_logging(
     Group,
     ModelFieldsLogConfig(
@@ -315,7 +314,8 @@ class Consequence(Model):
                 self.handler.execute(self)
                 from ephios.core.services.notifications.types import ConsequenceApprovedNotification
 
-                ConsequenceApprovedNotification.send(self)
+                if user != self.user:
+                    ConsequenceApprovedNotification.send(self)
         except Exception as e:  # pylint: disable=broad-except
             self.state = self.States.FAILED
             add_log_recorder(
@@ -340,7 +340,8 @@ class Consequence(Model):
         self.save()
         from ephios.core.services.notifications.types import ConsequenceDeniedNotification
 
-        ConsequenceDeniedNotification.send(self)
+        if user != self.user:
+            ConsequenceDeniedNotification.send(self)
 
     def render(self):
         return self.handler.render(self)
@@ -401,3 +402,6 @@ class Notification(Model):
 
     def as_html(self):
         return self.notification_type.as_html(self)
+
+    def get_url(self):
+        return self.notification_type.get_url(self)
