@@ -8,7 +8,7 @@ from django.views.generic.base import TemplateResponseMixin
 from django.views.generic.detail import SingleObjectMixin
 from django_select2.forms import ModelSelect2Widget
 
-from ephios.core.models import AbstractParticipation, Shift, UserProfile
+from ephios.core.models import AbstractParticipation, Qualification, Shift, UserProfile
 from ephios.extra.mixins import CustomPermissionRequiredMixin
 
 
@@ -42,14 +42,11 @@ class DispositionBaseModelFormset(forms.BaseModelFormSet):
     def add_prefix(self, index):
         return "%s-%s" % (self.prefix, self._start_index + index)
 
-    def delete_existing(self, obj, commit=True):
-        # refresh from db as obj has the state from the post data
-        db_obj = AbstractParticipation.objects.get(id=obj.id)
-        if db_obj.state != AbstractParticipation.States.GETTING_DISPATCHED:
-            raise ValueError(
-                "Deletion a participation is only allowed if it was just added through disposition."
-            )
-        super().delete_existing(obj, commit)
+    def save_existing(self, form, instance, commit=True):
+        """Existing participation state overwrites the getting dispatched state."""
+        if form.instance.state == AbstractParticipation.States.GETTING_DISPATCHED:
+            form.instance.state = AbstractParticipation.objects.get(id=form.instance.id).state
+        return form.save(commit=commit)
 
 
 def get_disposition_formset(form):
@@ -79,7 +76,12 @@ class AddUserForm(forms.Form):
         widget=ModelSelect2Widget(
             model=UserProfile,
             search_fields=["first_name__icontains", "last_name__icontains"],
-            attrs={"form": "add-user-form", "data-placeholder": _("search")},
+            attrs={
+                "form": "add-user-form",
+                "data-placeholder": _("search"),
+                "data-tags": "true",
+                "data-token-separators": [],
+            },
         ),
         queryset=UserProfile.objects.none(),  # set using __init__
     )
@@ -138,6 +140,39 @@ class AddUserView(DispositionBaseViewMixin, TemplateResponseMixin, View):
         raise Http404()
 
 
+class AddPlaceholderParticipantView(DispositionBaseViewMixin, TemplateResponseMixin, View):
+    def get_template_names(self):
+        return [
+            self.object.signup_method.disposition_participation_form_class.disposition_participation_template
+        ]
+
+    def post(self, request, *args, **kwargs):
+        shift = self.object
+        from ephios.core.signup import PlaceholderParticipant
+
+        participant = PlaceholderParticipant(
+            first_name=request.POST["first_name"],
+            last_name=request.POST["last_name"],
+            qualifications=Qualification.objects.none(),
+            email=None,
+            date_of_birth=None,
+        )
+        instance = shift.signup_method.get_participation_for(participant)
+        instance.state = AbstractParticipation.States.GETTING_DISPATCHED
+        instance.save()
+
+        DispositionParticipationFormset = get_disposition_formset(
+            self.object.signup_method.disposition_participation_form_class
+        )
+        formset = DispositionParticipationFormset(
+            queryset=AbstractParticipation.objects.filter(pk=instance.pk),
+            prefix="participations",
+            start_index=int(request.POST["new_index"]),
+        )
+        form = next(filter(lambda form: form.instance.id == instance.id, formset))
+        return self.render_to_response({"form": form, "shift": shift})
+
+
 class DispositionView(DispositionBaseViewMixin, TemplateView):
     template_name = "core/disposition/disposition.html"
 
@@ -158,7 +193,12 @@ class DispositionView(DispositionBaseViewMixin, TemplateView):
             formset.save()
 
             for participation, changed_fields in formset.changed_objects:
-                if "state" in changed_fields:
+                from ephios.core.models import LocalParticipation
+
+                if "state" in changed_fields and (
+                    not participation.get_real_instance_class() == LocalParticipation
+                    or participation.user != request.user
+                ):
                     if participation.state == AbstractParticipation.States.CONFIRMED:
                         from ephios.core.services.notifications.types import (
                             ParticipationConfirmedNotification,
@@ -174,7 +214,7 @@ class DispositionView(DispositionBaseViewMixin, TemplateView):
 
             self.object.participations.filter(
                 state=AbstractParticipation.States.GETTING_DISPATCHED
-            ).delete()
+            ).non_polymorphic().delete()
             return redirect(self.object.event.get_absolute_url())
         return self.get(request, *args, **kwargs, formset=formset)
 
