@@ -1,5 +1,6 @@
 import json
 
+from django import forms
 from dynamic_preferences.types import (
     BasePreferenceType,
     BaseSerializer,
@@ -14,7 +15,7 @@ class CustomModelMultipleChoicePreference(ModelMultipleChoicePreference):
         pass
 
 
-class DictSerializer(BaseSerializer):
+class JSONSerializer(BaseSerializer):
     @classmethod
     def clean_to_db_value(cls, value):
         return json.dumps(value, cls=CustomJSONEncoder)
@@ -24,5 +25,7 @@ class DictSerializer(BaseSerializer):
         return json.loads(value, cls=CustomJSONDecoder)
 
 
-class DictPreference(BasePreferenceType):
-    serializer = DictSerializer
+class JSONPreference(BasePreferenceType):
+    serializer = JSONSerializer
+    field_class = forms.CharField
+    widget = forms.Textarea
