@@ -50,6 +50,7 @@ INSTALLED_APPS = [
     "django.contrib.sessions",
     "django.contrib.messages",
     "django.contrib.staticfiles",
+    "django.contrib.humanize",
     "guardian",
     "django_select2",
     "djangoformsetjs",
@@ -58,6 +59,7 @@ INSTALLED_APPS = [
     "statici18n",
     "dynamic_preferences.users.apps.UserPreferencesConfig",
     "crispy_forms",
+    "crispy_bootstrap5",
     "webpush",
     "ephios.modellogging",
 ]
@@ -69,10 +71,10 @@ EPHIOS_CORE_MODULES = [
 INSTALLED_APPS += EPHIOS_CORE_MODULES
 
 CORE_PLUGINS = [
-    "ephios.plugins.basesignup",
-    "ephios.plugins.pages",
-    "ephios.plugins.guests",
-    "ephios.plugins.eventautoqualification",
+    "ephios.plugins.basesignup.apps.PluginApp",
+    "ephios.plugins.pages.apps.PluginApp",
+    "ephios.plugins.guests.apps.PluginApp",
+    "ephios.plugins.eventautoqualification.apps.PluginApp",
 ]
 PLUGINS = copy.copy(CORE_PLUGINS)
 for ep in importlib_metadata.entry_points().get("ephios.plugins", []):
@@ -82,6 +84,8 @@ INSTALLED_APPS += PLUGINS
 
 INSTALLED_APPS += ["dynamic_preferences"]  # must come after our apps to collect preferences
 
+DEFAULT_AUTO_FIELD = "django.db.models.BigAutoField"
+
 MIDDLEWARE = [
     "django.middleware.security.SecurityMiddleware",
     "django.contrib.sessions.middleware.SessionMiddleware",
@@ -182,6 +186,8 @@ STATICFILES_FINDERS = (
     "compressor.finders.CompressorFinder",
 )
 COMPRESS_ENABLED = not DEBUG
+# https://www.accordbox.com/blog/how-use-scss-sass-your-django-project-python-way/
+COMPRESS_PRECOMPILERS = (("text/x-scss", "django_libsass.SassCompiler"),)
 
 # mail configuration
 EMAIL_CONFIG = env.email_url("EMAIL_URL")
@@ -223,7 +229,7 @@ SELECT2_CSS = ""
 SELECT2_I18N_PATH = ""
 
 # django-debug-toolbar
-if DEBUG:
+if DEBUG and env.bool("DEBUG_TOOLBAR", True):
     INSTALLED_APPS.append("django_extensions")
     INSTALLED_APPS.append("debug_toolbar")
     MIDDLEWARE.insert(0, "debug_toolbar.middleware.DebugToolbarMiddleware")
@@ -238,7 +244,8 @@ CSP_STYLE_SRC = ("'self'",)
 CSP_INCLUDE_NONCE_IN = ["style-src"]
 
 # django-crispy-forms
-CRISPY_TEMPLATE_PACK = "bootstrap4"
+CRISPY_ALLOWED_TEMPLATE_PACKS = "bootstrap5"
+CRISPY_TEMPLATE_PACK = "bootstrap5"
 CRISPY_FAIL_SILENTLY = not DEBUG
 
 # django.contrib.messages
