@@ -1,8 +1,24 @@
 function handleForms(elem) {
     // Configure the subtree specified by the root elem (jquery object) for use
     // with the various JS libs
-    elem.find('[data-toggle="tooltip"]').tooltip();
-    elem.find(".django-select2").djangoSelect2()
+    elem.find('[data-bs-toggle="tooltip"]').tooltip();
+
+    // https://getbootstrap.com/docs/5.0/components/popovers/
+    elem.find('[data-bs-toggle="popover"]').each((idx, el) => {
+        new bootstrap.Popover(el, {
+            html: true,
+            content: function () {
+                return $(el.getAttribute("data-bs-content-ref")).html();
+            },
+            title: function () {
+                return $(el.getAttribute("data-title-ref")).html();
+            }
+        });
+    });
+
+    elem.find(".django-select2").djangoSelect2({
+        theme: "bootstrap5"
+    });
     elem.find("[data-formset]").formset({
         animateForms: true,
         reorderMode: 'dom',
